package com.lantone.qc.trans.wenfuyi.util;

import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.lantone.qc.pub.util.StringUtil;
import com.lantone.qc.trans.comsis.CommonAnalysisUtil;
import lombok.extern.slf4j.Slf4j;
import org.jsoup.Jsoup;
import org.jsoup.nodes.Element;

import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @author: rengb
 * @time: 2020/9/28 16:36
 */
@Slf4j
public class OperationRecordHtmlAnalysis implements WenFuYiHtmlAnalysis {

    private String modeId = "17";

    @Override
    public Map<String, String> analysis(String... args) {
        Map<String, String> map = Maps.newLinkedHashMap();
        try {
            String html = args[0];
            String recTitle = args[1];
            String recTypeId = args[2];
            String content = Jsoup.parse(html.replace("<br>", "<div>")).selectFirst("body").children().text();
            analysisGeneral(content, map);
            WenFuYiHtmlAnalysisUtil.mapValueRemoveStartColon(map);
            CommonAnalysisUtil.makeEmpty(map, "医生签名");
            WenFuYiHtmlAnalysisUtil.insertModuleId(modeId, recTypeId, map);
        } catch (Exception e) {
            log.error(e.getMessage(), e);
        }
        return map;
    }

    private void analysisGeneral(String content, Map<String, String> map) {
        content = content.replace("注:如果手术记录中的手术日期有变更，必须重新点击“编辑手术名称”按钮保存。", "");

        int index1 = content.lastIndexOf("总产程");
        int index2 = content.lastIndexOf("出血原因");
        if (index1 != -1 && index2 != -1) {
            content = content.substring(0, index1)
                    + content.substring(index1, index2).replace("其他", "胎盘其他")
                    + content.substring(index2).replace("其他", "产后其他");
        }

        List<String> titles = Lists.newArrayList(
                "手术开始时间", "手术结束时间", "手术日期", "术前诊断", "术中诊断", "手术指征", "手术名称", "主刀医师", "一助", "二助", "麻醉方式", "麻醉者", "手术方式", "手术经过", "体位及手术径路", "探查(术中所见)",
                "操作步骤", "手术经过(手术小结)", "主刀签名", "记录者", "记录时间", "记录日期", "术后诊断", "手术者", "助者", "麻醉", "手术经过", "术者/操作者签名",
                "破膜", "破膜方式", "娩出胎位", "第一产程", "宫缩开始", "第二产程", "宫口开全", "第三产程", "胎儿娩出", "胎盘娩出", "总产程", "胎盘其他", "脐带", "清后羊水性状", "羊水数量", "会阴", "会阴裂伤", "产时用药", "麻醉方式",
                "产后出血", "出血原因", "产后其他", "新生儿", "胎数", "分娩概况", "手术指征", "手术方式", "诊断", "阴道分娩纱布清点", "送休养室时间", "接生者", "记录者", "记录时间"
        );
        titles = CommonAnalysisUtil.sortTitles(titles, content);
        CommonAnalysisUtil.cutByTitlesNoColon(content, titles, 0, map);
        if (StringUtil.isNotBlank(map.get("送休养室时间"))) {
            map.put("送休养室时间", CommonAnalysisUtil.WFYExtractDate(map.get("送休养室时间")));
        }
    }

}